@@ -5,7 +5,9 @@ from .wrappers import cmd_run_in_pty
 _COMMIT_BASE_COMMAND = ["git", "commit", "-v"]
 
 
-def _commit_with_message(message: str, amend: bool = False) -> bool:
+def _commit_with_message(
+    message: str, amend: bool = False, no_verify: bool = False
+) -> bool:
     cmd = [*_COMMIT_BASE_COMMAND, "-m", message]
 
     if amend:
@@ -19,20 +21,26 @@ def _commit_with_message(message: str, amend: bool = False) -> bool:
 
         cmd.append("--amend")
 
+    if no_verify:
+        cmd.append("-n")
+
     return 0 == cmd_run_in_pty(*cmd)[0]
 
 
-def _commit_without_message(amend: bool = False) -> bool:
+def _commit_without_message(amend: bool = False, no_verify: bool = False) -> bool:
     cmd = [*_COMMIT_BASE_COMMAND]
 
     if amend:
         cmd.append("--amend")
 
+    if no_verify:
+        cmd.append("-n")
+
     return 0 == cmd_run_in_pty(*cmd)[0]
 
 
-def commit(message: str, amend: bool = False) -> bool:
+def commit(message: str, amend: bool = False, no_verify: bool = False) -> bool:
     if message:
-        return _commit_with_message(message, amend=amend)
+        return _commit_with_message(message, amend=amend, no_verify=no_verify)
     else:
-        return _commit_without_message(amend=amend)
+        return _commit_without_message(amend=amend, no_verify=no_verify)
